"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_client_1 = require("./http-client");
var sl_routes_1 = require("./sl-routes");
var entities_mapper_1 = require("./entities-mapper");
var constants_1 = require("../constants/constants");
var BackendProxy = /** @class */ (function () {
    function BackendProxy(config, logger) {
        this.config = config;
        this.logger = logger;
        this.client = new http_client_1.HttpClient(this.config, this.logger);
    }
    BackendProxy.prototype.getBuildSession = function (buildSessionId, callback) {
        var _this = this;
        this.verifyNotNullOrUndefined(buildSessionId, "buildSessionId");
        var url = sl_routes_1.SLRoutes.buildSessionV2(buildSessionId);
        this.client.get(url, function (err, body) {
            _this.invokeCallback(callback, err, body, entities_mapper_1.EntitiesMapper.toBuildSessionData);
        });
    };
    BackendProxy.prototype.createBuildSessionId = function (request, callback) {
        var _this = this;
        this.verifyNotNullOrUndefined(request);
        var url = sl_routes_1.SLRoutes.buildSessionV2();
        this.client.post(request, url, function (err, body) {
            _this.invokeCallback(callback, err, body, entities_mapper_1.EntitiesMapper.toCreateBuildSessionIdResponse);
        });
    };
    BackendProxy.prototype.getRecommendedVersion = function (request) {
        var _this = this;
        this.verifyNotNullOrUndefined(request);
        var url = sl_routes_1.SLRoutes.recommendedAgentV2(request.componentName, request.customerId, request.appName, request.branchName, request.testStage);
        return new Promise(function (resolve, reject) {
            _this.client.get(url, function (err, body) {
                if (err) {
                    return reject(err);
                }
                else if (body && body.agent && body.agent) {
                    return resolve(body.agent);
                }
                else {
                    return reject(new Error("Failed to get recommended version due to unexpected response from the server."));
                }
            });
        });
    };
    BackendProxy.prototype.submitBuildMapping = function (request) {
        var _this = this;
        this.verifyNotNullOrUndefined(request);
        var url = sl_routes_1.SLRoutes.buildMappingV3();
        return new Promise(function (resolve, reject) {
            _this.client.post(request, url, function (err, body) {
                if (err) {
                    return reject(err);
                }
                return resolve(body);
            });
        });
    };
    BackendProxy.prototype.submitLogs = function (request, callback) {
        var _this = this;
        this.verifyNotNullOrUndefined(request);
        var url = sl_routes_1.SLRoutes.logSubmissionV2();
        this.client.post(request, url, function (err, body) {
            _this.invokeCallback(callback, err, body);
        });
    };
    BackendProxy.prototype.getRemoteConfig = function (request, callback) {
        var _this = this;
        this.verifyNotNullOrUndefined(request);
        var url = sl_routes_1.SLRoutes.configV2(request.component, request.customerId, request.appName, request.branch, request.testStage, request.version);
        this.client.get(url, function (err, body) {
            _this.invokeCallback(callback, err, body, entities_mapper_1.EntitiesMapper.toGetRemoteConfigResponse);
        });
    };
    BackendProxy.prototype.invokeCallback = function (callback, err, body, map) {
        this.verifyNotNullOrUndefined(callback, "callback");
        if (err != null) {
            return callback(err, body);
        }
        if (map == null) {
            return callback(null, body);
        }
        var apiResponse = map(body);
        return callback(null, apiResponse);
    };
    BackendProxy.prototype.verifyNotNullOrUndefined = function (request, paramName) {
        paramName = paramName || "Request";
        if (!request)
            throw new Error(paramName + " " + constants_1.Constants.Messages.CANNOT_BE_NULL_OR_UNDEFINED + ".");
    };
    return BackendProxy;
}());
exports.BackendProxy = BackendProxy;
